# Contributing

Thank you for contributing to the goodness of this project.

## Creating Issues

If this is a bug:

1. Describe the failure.
2. Include reproduction steps.
3. Include the expected result.

If this is a feature request:

1. Describe the feature.
2. Provide a user story. (As a ___, I need ___ so that I can ___.)
3. Describe the benefits of the feature.

## Submitting Patches

When you submit a patch, please:

1. Include test steps.
2. If possible, please provide unit tests.
3. If possible, please provide functional tests.

## Development Environment Setup

Before you check out this code, install Drupal 10 locally using
[ddev](https://drupalize.me/tutorial/install-drupal-locally-ddev).

```shell
mkdir drupal-vite-react-generator
cd drupal-vite-react-generator
ddev config --project-type drupal10 --create-docroot --docroot web
ddev start
ddev composer create drupal/recommended-project -y
ddev composer require --dev drush/drush
ddev drush site:install --account-name=admin --account-pass=admin -y
ddev composer require --dev drupal/core-dev
```

Now, create the "contrib modules" directory.

```shell
mkdir -p web/modules/contrib
```

Go to that directory, clone this repository, and install this module.

## Updating the Templates

> See
> [Scaffolding Your First Vite Project](https://vitejs.dev/guide/#scaffolding-your-first-vite-project).

Execute the following to install React with Vite
for "React with Babel" and "React with SWC."

```shell
source templates/init.sh
```

## Testing

To run the PHPUnit tests, execute:

### To Run All the Tests

```shell
ddev exec -d /var/www/html/web/modules/contrib/vite_react_generator bash ./scripts/all-tests.sh
```

### To Run the Unit Tests

```shell
ddev exec -d /var/www/html/web/modules/contrib/vite_react_generator bash ./scripts/unit-tests.sh
```

### To Run the Functional Tests

```shell
ddev exec -d /var/www/html/web/modules/contrib/vite_react_generator bash ./scripts/functional-tests.sh
```

### To Run PHPCS

```shell
ddev exec -d /var/www/html/web/modules/contrib/vite_react_generator bash ./scripts/lint.sh
```

### To Run PHPCBF

```shell
ddev exec -d /var/www/html/web/modules/contrib/vite_react_generator bash ./scripts/lint-fix.sh
```

---

The Exploratorium is a 501(c)(3) nonprofit organization. Our tax ID #: 94-1696494

https://www.exploratorium.edu
