#!/usr/bin/env bash

set -e

cd "$(dirname "$0")"

for transpiler in babel swc ; do
  echo ">>> $transpiler"
  if [ -d $transpiler ]; then
    rm -rf $transpiler
  fi

  echo ">>> $transpiler: Creating project"
  if [ "$transpiler" == "babel" ]; then
    npm create vite babel -- --template react
  else
    npm create vite swc -- --template react-swc
  fi

  echo ">>> $transpiler: Configuring project"
  (
    cd $transpiler

    echo ">>> $transpiler: Installing dependencies"
    npm install

    echo ">>> $transpiler: Adding required dependencies"
    npm install --save-dev \
        rollup-plugin-drupal-interface-translations \
        rollup-plugin-drupal-sdc-generator \
        rollup-plugin-inject-process-env

    echo ">>> $transpiler: Adding code quality helpers"
    npm install --save-dev prettier prop-types \
        eslint-plugin-simple-import-sort eslint-plugin-unused-imports@^3.0.0 \
        eslint-plugin-prettier eslint-config-prettier

    echo ">>> $transpiler: Adding testing frameworks"
    npm install --save-dev vitest @vitest/ui \
        @testing-library/react @testing-library/dom \
        cypress @testing-library/cypress
  )
done
