<?php

namespace Drupal\Tests\vite_react_generator\Functional;

use Drupal\vite_react_generator\Drush\Generators\ReactComponentGenerator;
use DrupalCodeGenerator\Test\Functional\GeneratorTestBase;

/**
 * Tests single-directory-component-vite-react generator.
 */
final class ReactComponentGeneratorTest extends GeneratorTestBase {

  /**
   * {@inheritdoc}
   */
  protected string $fixtureDir = __DIR__ . '/_swc_testing';

  /**
   * Test callback.
   */
  public function testGenerator(): void {
    $input = [
      'foo',
      'Foo',
      'Bar',
      'bar',
      'Some description.',
      'Speedy Web Compiler',
      'Yes',
    ];
    $this->execute(ReactComponentGenerator::class, $input);

    $expected_display = <<< 'TXT'

     Welcome to sdc-vite-react generator!
    ––––––––––––––––––––––––––––––––––––––

     Module machine name:
     ➤

     Module name [Foo]:
     ➤

     Component name [Foo]:
     ➤

     Component machine name [bar]:
     ➤

     Component description (optional):
     ➤

     Transpiler [Speedy Web Compiler]:
      [1] Speedy Web Compiler
      [2] Babel
     ➤

     Install testing frameworks? [No]:
     ➤

     The following directories and files have been created or updated:
    –––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
     • .eslintrc.cjs
     • .gitignore
     • .prettierrc.json
     • foo.info.yml
     • package.json
     • README.md
     • vite.config.js
     • js/index.html
     • js/public/index.css
     • js/src/App.css
     • js/src/App.jsx
     • js/src/main.jsx
     • js/src/assets/exploratorium.svg

    TXT;
    $expected_display = str_replace('➤', '➤ ', $expected_display);
    $this->assertDisplay($expected_display);

    foreach ([
      '.gitignore',
      'foo.info.yml',
      'package.json',
      'README.md',
      'vite.config.js',
      'js/index.html',
      'js/public/index.css',
      'js/src/main.jsx',
    ] as $file) {
      $this->assertGeneratedFile($file);
    }

    foreach ([
      '.eslintrc.cjs',
      '.prettierrc.json',
      'js/src/App.css',
      'js/src/App.jsx',
    ] as $file) {
      $this->assertFileExists($this->directory . '/' . $file);
    }
  }

}
